# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = "Grafica"
copyright = "2025, Jacob Sánchez"
author = "Jacob Sánchez"
release = "0.1.0"

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = []

templates_path = ["_templates"]
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]

language = "es"

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_theme = "grafica"
html_theme_options = {
    "description": "Un tema de Sphinx basado en gob.mx",
    "github_user": "sanjacob",
    "github_repo": "grafica",
}



from pathlib import Path
from importlib.metadata import version


def setup(app):
    __version__ = version("grafica")

    app.add_html_theme("grafica", Path(__file__).resolve().parent)

    return {
        "version": __version__,
        "parallel_read_safe": True,
        "parallel_write_safe": True,
    }
